#!/bin/sh

# ------------------------------------------------------------------------------
# YourKit Java Profiler startup script
# ------------------------------------------------------------------------------

if [ "`uname | grep Linux`" ] ; then
  Y0=`readlink -f "$0"`
else
  Y0=`readlink "$0" 2>/dev/null`
fi
if [ -z "$Y0" ] ; then
  Y0="$0"
fi

YH="$YOURKIT_HOME"
if [ -z "$YH" ] ; then
  YH="$HOME"
fi

YS="$YH/.yjp"
if [ -z "$YH" ] ; then
  YH="$HOME"
fi

YD=`dirname "$Y0"`/..

# macOS: exit early on restart, to avoid further Java path checks failing if Java is not installed
if [ `uname` = "Darwin" ] ; then
  if [ "`echo $@ | grep ideport`" ] || [ "`echo $@ | grep restart_for_update`" ] ; then
    "$YD/../MacOS/profiler" &
    exit 0
  fi
fi

if [ ! -z "$YJP_JAVA_HOME" ] ; then
  JAVA_EXE="$YJP_JAVA_HOME/bin/java"
  if [ ! -r "$JAVA_EXE" ] ; then
    JAVA_EXE="$YJP_JAVA_HOME/jre/bin/java"
  fi
elif [ `uname` = "Darwin" ] ; then
  JAVA_EXE="$YD/../jdk/Contents/Home/jre/bin/java"
elif [ "`uname | grep Linux`" ] ; then
  if [ "`uname -m | grep x86_64`" ] ; then
    if [ "`getconf LONG_BIT | grep 64`" ] ; then
      JAVA_EXE="$YD/jre64/bin/java"
    fi
  fi
fi

if [ ! -r "$JAVA_EXE" ] && [ ! -z "$JAVA_HOME" ] ; then
  JAVA_EXE="$JAVA_HOME/bin/java"
fi

if [ ! -r "$JAVA_EXE" ] ; then
  JAVA_EXE=java
fi

# Force 64-bit Java on HP-UX
if [ "`uname | grep HP-UX`" ] ; then
  D64="-d64"
else
  D64=""
fi

JAVA_VERSION="`\"$JAVA_EXE\" $D64 -version 2>&1`"

if [ -z "`echo $JAVA_VERSION | grep version`" ] ; then
  echo "Cannot find Java 11 to run YourKit Java Profiler."
  echo "Java search sequence:"
  echo " - environment variable YJP_JAVA_HOME"
  if [ "`uname | grep Linux`" ] ; then
    if [ "`uname -m | grep x86_64`" ] ; then
      echo " - bundled JRE"
    fi
  fi
  echo " - environment variable JAVA_HOME"
  echo " - 'java' in PATH"
  exit
fi

unset JAVA_TOOL_OPTIONS

if [ "`echo $JAVA_VERSION | grep 64-Bit`" ] ; then
  # 64-Bit Java
  JAVA_HEAP_LIMIT="-Xmx8G"
else
  # 32-Bit Java
  JAVA_HEAP_LIMIT="-Xmx128m"
fi

# If you use Xmonad window manager, uncomment next 3 lines:
# _JAVA_AWT_WM_NONREPARENTING=1
# export _JAVA_AWT_WM_NONREPARENTING
# wmname LG3D

if [ -f "$YS/ui.ini" ] ; then
  INI_PARAMS="`cat $YS/ui.ini | grep -v '#'`"
else
  INI_PARAMS="-Dyjp.no.ui.ini"
fi

INI_PARAMS="-Djava.awt.smartInvalidate=true $INI_PARAMS"

if [ `uname` = "Darwin" ] ; then
  UI_PARAMS=-Dapple.laf.useScreenMenuBar=true
else
  UI_PARAMS=
fi

if [ "`echo $@ | grep ideport`" ] || [ "`echo $@ | grep restart_for_update`" ] ; then
  exec "$JAVA_EXE" $D64 $JAVA_HEAP_LIMIT $INI_PARAMS $UI_PARAMS -jar "$YD/lib/yourkit.jar" $1 $2 $3 $4 $5 $6 $7 $8 $9 &
else
  exec "$JAVA_EXE" $D64 $JAVA_HEAP_LIMIT $INI_PARAMS $UI_PARAMS -jar "$YD/lib/yourkit.jar" $1 $2 $3 $4 $5 $6 $7 $8 $9
fi
